.. template documentation master file, created by
   sphinx-quickstart on Thu Sep 04 12:36:36 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to template's documentation!
====================================
Contents:

.. toctree::
   :maxdepth: 2

   conf.py


Indices and tables
------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
